import 'package:libaqueous/src/api/client.dart';
import 'package:libaqueous/src/api/data/timeline.dart';
import 'package:libaqueous/src/api/data/timeline_holder.dart';
import 'package:rxdart/rxdart.dart';

abstract class RoomEmitter {
  Observable<String> get nameObservable;

  Observable<String> get topicObservable;

  Observable<Uri> get avatarUrlObservable;

  Observable<String> get canonicalAliasObservable;

  Observable<List<String>> get membersObservable;

  Observable<Timeline> get timelineObservable;
}

abstract class Room implements RoomEmitter, TimelineHolder<Timeline> {
  Client get client;

  String get id;

  String get name;

  String get topic;

  String get displayName;

  Uri get avatarUrl;

  String get canonicalAlias;

  bool get isDirect;

  String get directUserID;

  Map<String, double> get tags;

  bool get isFavourite;

  bool get isLowPriority;

  String get prevToken;

  bool get hasFullMembers;

  List<String> get memberIDs;

  String get userMembership;

  int get unreadEventCount;

  int get notificationCount;

  int get highlightCount;

  Future<void> postMessage(Map<String, dynamic> body);

  Future<void> postPlainText(String text);

  Future<void> postEmote(String text);

  Future<void> getEarlierMessages(int limit);

  Future<void> getPreviousEvents(int limit);

  Future<void> fetchMembers();
}
