import 'dart:async';

import 'package:libaqueous/src/client/default_room.dart';
import 'package:libaqueous/src/client/default_user.dart';
import 'package:libaqueous/src/rest/events/model/event.dart';
import 'package:libaqueous/src/rest/events/model/tokens_chunk_events.dart';

abstract class Store {
  Future<void> open();

  Future<void> close();

  Future<void> commit();

  Future<void> clear();

  bool get isPermanent => false;

  Future<String> syncToken();

  Future<void> setSyncToken(String token);

  Future<bool> containsRoomData(String id);

  Future<DefaultRoomData> roomData(String id);

  Future<Map<String, DefaultRoomData>> roomDataBulk();

  Future<void> storeRoomData(String id, DefaultRoomData roomData);

  Future<void> storeRoomDataBulk(Map<String, DefaultRoomData> roomDatas);

  Future<void> deleteRoomData(String id);

  Future<bool> containsUserData(String id);

  Future<DefaultUserData> userData(String id);

  Future<Map<String, DefaultUserData>> userDataBulk();

  Future<void> storeUserData(String id, DefaultUserData userData);

  Future<void> storeUserDataBulk(Map<String, DefaultUserData> userDatas);

  Future<void> deleteUserData(String id);

  Future<void> storeBackToken(String id, String token);

  Future<void> storeLiveRoomEvent(Event event);

  Future<void> storeRoomEvents(
      String id, TokensChunkEvents tokensChunkEvents, bool isHistory);

  Future<TokensChunkEvents> getEarlierMessages(
      String id, String fromToken, int limit);
}
